use crate::apis::Error;
use uuid::Uuid;

pub fn map_autogenerated_error<T, U, M>(err: Error<T>, unexpected_error: U, map: M) -> U
where
    M: Fn(reqwest::StatusCode, Option<T>) -> U,
{
    match err {
        Error::Reqwest(_) => return unexpected_error,
        Error::Serde(_) => return unexpected_error,
        Error::Io(_) => return unexpected_error,
        Error::ResponseError(response_content) => {
            map(response_content.status, response_content.entity)
        }
    }
}

pub fn is_valid_id(id: &str) -> bool {
    Uuid::parse_str(id).is_ok()
}
